@@ -42,7 +42,7 @@ def docker_compose_lines(__docker_compose_src: str):
             if "=" in ffl:
                 results.append(ffl)
             elif ":" in ffl:
-                lhs,rhs = ffl.split(":",1)
+                lhs, rhs = ffl.split(":", 1)
                 ffl = f"{lhs.rstrip()}={rhs.lstrip()}"
                 results.append(ffl)
         else:
@@ -129,3 +129,20 @@ class Env(BaseModel):
 
     """
     return result
+
+
+def form_dockerfile_env_src(
+    __dict: dict[str, str], dockerfile_path: str = "Dockerfile"
+):
+    dockerfile_lines = []
+    if path_exists(dockerfile_path):
+        dockerfile_env_src = read_text(dockerfile_path)
+        dockerfile_lines = dockerfile_env_src.splitlines(keepends=False)
+    dockerfile_lines = [line for line in dockerfile_lines if not line.startswith("ENV")]
+    endline = ""
+    if dockerfile_lines:
+        endline = dockerfile_lines[-1]
+        dockerfile_lines = dockerfile_lines[:-1]
+    env_lines = [f"ENV {key}={value}" for key, value in __dict.items()]
+    result = dockerfile_lines + env_lines + [endline]
+    return "\n".join(result)
